#ifndef _SCR_FRYEBOX_H
#define _SCR_FRYEBOX_H
/*
 * original from Epson Research & Development Vancouver Design center,
 * hacked on by aaron@frye.com for purposes of multi-chip support.
 */

/*
 * common macros between the two chips
 */

#ifndef VID_MEMBASE	/* base of video memory */
#define VID_MEMBASE	0x400000
#endif	/* VMEM_BASE */

#ifndef VID_MEMSIZE	/* size of video memory in bytes */
#define VID_MEMSIZE	2*1024*1024
#endif	/* VMEM_SIZE */

#ifndef VID_ICLK	/* input clock in megahertz */
#if 1
#define	VID_ICLK	25.175
#else
#define	VID_ICLK	40.000
#endif
#endif	/* VID_ICLK */

/* S1D13505 memory base */
#ifndef VID505_REGBASE	/* base of register memory */
#define VID505_REGBASE	0xfff800
#endif	/* VID505_REGBASE */

/* S1D13506 memory base */
#ifndef VID506_REGBASE	/* base of register memory */
#define VID506_REGBASE	0xc00000
#endif	/* VID506_REGBASE */

/* S1D13506 BitBLT memory base */
#ifndef VID506_BLTBASE	/* base of BitBLT memory window */
#define VID506_BLTBASE	(VID506_REGBASE+0x100000)
#endif	/* VID506_BLTBASE */

/* helper macros */

/* access video registers */
#ifdef __ASSEMBLER__	/* we're in assembler */
#define VID505_REG(regoffset)	(VID505_REGBASE+regoffset)
#define VID505_MEM(memoffset)	(VID505_MEMBASE+memoffset)
#else 			/* we're doing C */
#define VID505_REG(regoffset) \
    (*(volatile unsigned char *)(VID505_REGBASE + regoffset))
#define VID505_MEM(memoffset) \
    (*(volatile unsigned char *)(VID505_MEMBASE + memoffset))
#define VID505_MEM16(memoffset) \
    (*(volatile unsigned short *)(VID505_MEMBASE + memoffset))
#define VID505_MEM32(memoffset) \
    (*(volatile unsigned int *)(VID505_MEMBASE + memoffset))
#endif	/* __ASSEMBLER__ */

/* access video registers
 * FIXME we assume the size of char, int, and short... */
#ifdef __ASSEMBLER__	/* we're in assembler */
#define VID506_REG(regoffset)	(VID506_REGBASE+regoffset)
#define VID506_MEM(memoffset)	(VID506_MEMBASE+memoffset)
#else 			/* we're doing C */
#define VID506_REG(regoffset) \
    (*(volatile unsigned char *)(VID506_REGBASE + regoffset))
#define VID506_MEM(memoffset) \
    (*(volatile unsigned char *)(VID506_MEMBASE + memoffset))
#define VID506_MEM16(memoffset) \
    (*(volatile unsigned short *)(VID506_MEMBASE + memoffset))
#define VID506_BLTMEM16(memoffset) \
    (*(volatile unsigned short *)(VID506_BLTBASE + memoffset))
#define VID506_MEM32(memoffset) \
    (*(volatile unsigned int *)(VID506_MEMBASE + memoffset))
#endif	/* __ASSEMBLER__ */

/*
 * registers for the S1D13505
 */
#define VID505_REVISION_CODE		0x00
#define VID505_MEMORY_CONFIG		0x01
#define VID505_PANEL_TYPE		0x02
#define VID505_MOD_RATE			0x03
#define VID505_HORZ_DISP_WIDTH		0x04
#define VID505_HORZ_NONDISP_PERIOD	0x05
#define VID505_HRTC_START_POSITION	0x06
#define VID505_HRTC_PULSE_WIDTH		0x07
#define VID505_VERT_DISP_HEIGHT0	0x08
#define VID505_VERT_DISP_HEIGHT1	0x09
#define VID505_VERT_NONDISP_PERIOD	0x0A
#define VID505_VRTC_START_POSITION	0x0B
#define VID505_VRTC_PULSE_WIDTH		0x0C
#define VID505_DISPLAY_MODE		0x0D
#define VID505_SCRN1_LINE_COMPARE0	0x0E
#define VID505_SCRN1_LINE_COMPARE1	0x0F
#define VID505_SCRN1_DISP_START_ADDR0	0x10
#define VID505_SCRN1_DISP_START_ADDR1	0x11
#define VID505_SCRN1_DISP_START_ADDR2	0x12
#define VID505_SCRN2_DISP_START_ADDR0	0x13
#define VID505_SCRN2_DISP_START_ADDR1	0x14
#define VID505_SCRN2_DISP_START_ADDR2	0x15
#define VID505_MEM_ADDR_OFFSET0		0x16
#define VID505_MEM_ADDR_OFFSET1		0x17
#define VID505_PIXEL_PANNING		0x18
#define VID505_CLOCK_CONFIG		0x19
#define VID505_POWER_SAVE_CONFIG	0x1A
#define VID505_MISC			0x1B
#define VID505_MD_CONFIG_READBACK0	0x1C
#define VID505_MD_CONFIG_READBACK1	0x1D
#define VID505_GPIO_CONFIG0		0x1E
#define VID505_GPIO_CONFIG1		0x1F
#define VID505_GPIO_CONTROL0		0x20
#define VID505_GPIO_CONTROL1		0x21
#define VID505_PERF_ENHANCEMENT0	0x22
#define VID505_PERF_ENHANCEMENT1	0x23
#define VID505_LUT_ADDR			0x24
#define VID505_RESERVED_1		0x25
#define VID505_LUT_DATA			0x26
#define VID505_INK_CURSOR_CONTROL	0x27
#define VID505_CURSOR_X_POSITION0	0x28
#define VID505_CURSOR_X_POSITION1	0x29
#define VID505_CURSOR_Y_POSITION0	0x2A
#define VID505_CURSOR_Y_POSITION1	0x2B
#define VID505_INK_CURSOR_COLOR0_0	0x2C
#define VID505_INK_CURSOR_COLOR0_1	0x2D
#define VID505_INK_CURSOR_COLOR1_0	0x2E
#define VID505_INK_CURSOR_COLOR1_1	0x2F
#define VID505_INK_CURSOR_START_ADDR	0x30
#define VID505_ALTERNATE_FRM		0x31

/*
 * registers for the S1D13506
 */
#define VID506_REVISION_CODE              0x00
#define VID506_MISC                       0x01
#define VID506_GPIO_CONFIG                0x04
#define VID506_GPIO_CTRL                  0x08
#define VID506_MD_CFG_STATUS0             0x0c
#define VID506_MD_CFG_STATUS1             0x0d
#define VID506_MEM_CLOCK_CFG              0x10
#define VID506_LCD_PCLK_CFG               0x14
#define VID506_CRTTV_PCLK_CFG             0x18
#define VID506_MPCLK_CFG                  0x1c
#define VID506_CPU2MEM_WAIT_SEL           0x1e
#define VID506_MEM_CFG                    0x20
#define VID506_DRAM_REFRESH               0x21
#define VID506_DRAM_TIMINGS_CTRL0         0x2a
#define VID506_DRAM_TIMINGS_CTRL1         0x2b
#define VID506_PANEL_TYPE                 0x30
#define VID506_MOD_RATE                   0x31
#define VID506_LCD_HDP                    0x32
#define VID506_LCD_HNDP                   0x34
#define VID506_TFT_FPLINE_START           0x35
#define VID506_TFT_FPLINE_PULSE           0x36
#define VID506_LCD_VDP0                   0x38
#define VID506_LCD_VDP1                   0x39
#define VID506_LCD_VNDP                   0x3a
#define VID506_TFT_FPFRAME_START          0x3b
#define VID506_TFT_FPFRAME_PULSE          0x3c
#define VID506_LCD_LINE_COUNT0            0x3e
#define VID506_LCD_LINE_COUNT1            0x3f
#define VID506_LCD_DISPLAY_MODE           0x40
#define VID506_LCD_MISC                   0x41
#define VID506_LCD_START_ADDR0            0x42
#define VID506_LCD_START_ADDR1            0x43
#define VID506_LCD_START_ADDR2            0x44
#define VID506_LCD_MEM_ADDR_OFFSET0       0x46
#define VID506_LCD_MEM_ADDR_OFFSET1       0x47
#define VID506_LCD_PIXEL_PANNING          0x48
#define VID506_LCD_FIFO_HIGH_THRESHOLD    0x4a
#define VID506_LCD_FIFO_LOW_THRESHOLD     0x4b
#define VID506_CRTTV_HDP                  0x50
#define VID506_CRTTV_HNDP                 0x52
#define VID506_CRTTV_HRTC_START           0x53
#define VID506_CRT_HRTC_PULSE             0x54
#define VID506_CRTTV_VDP0                 0x56
#define VID506_CRTTV_VDP1                 0x57
#define VID506_CRTTV_VNDP                 0x58
#define VID506_CRTTV_VRTC_START           0x59
#define VID506_CRT_VRTC_PULSE             0x5a
#define VID506_TV_OUTPUT_CTRL             0x5b
#define VID506_CRTTV_LINE_COUNT0          0x5e
#define VID506_CRTTV_LINE_COUNT1          0x5f
#define VID506_CRTTV_DISPLAY_MODE         0x60
#define VID506_CRTTV_START_ADDR0          0x62
#define VID506_CRTTV_START_ADDR1          0x63
#define VID506_CRTTV_START_ADDR2          0x64
#define VID506_CRTTV_MEM_ADDR_OFFSET0     0x66
#define VID506_CRTTV_MEM_ADDR_OFFSET1     0x67
#define VID506_CRTTV_PIXEL_PANNING        0x68
#define VID506_CRTTV_FIFO_HIGH_THRESHOLD  0x6a
#define VID506_CRTTV_FIFO_LOW_THRESHOLD   0x6b
#define VID506_LCD_INK_CURS_CTRL          0x70
#define VID506_LCD_INK_CURS_START_ADDR    0x71
#define VID506_LCD_CURSOR_X_POS0          0x72
#define VID506_LCD_CURSOR_X_POS1          0x73
#define VID506_LCD_CURSOR_Y_POS0          0x74
#define VID506_LCD_CURSOR_Y_POS1          0x75
#define VID506_LCD_INK_CURS_BLUE0         0x76
#define VID506_LCD_INK_CURS_GREEN0        0x77
#define VID506_LCD_INK_CURS_RED0          0x78
#define VID506_LCD_INK_CURS_BLUE1         0x7a
#define VID506_LCD_INK_CURS_GREEN1        0x7b
#define VID506_LCD_INK_CURS_RED1          0x7c
#define VID506_LCD_INK_CURS_FIFO          0x7e
#define VID506_CRTTV_INK_CURS_CTRL        0x80
#define VID506_CRTTV_INK_CURS_START_ADDR  0x81
#define VID506_CRTTV_CURSOR_X_POS0        0x82
#define VID506_CRTTV_CURSOR_X_POS1        0x83
#define VID506_CRTTV_CURSOR_Y_POS0        0x84
#define VID506_CRTTV_CURSOR_Y_POS1        0x85
#define VID506_CRTTV_INK_CURS_BLUE0       0x86
#define VID506_CRTTV_INK_CURS_GREEN0      0x87
#define VID506_CRTTV_INK_CURS_RED0        0x88
#define VID506_CRTTV_INK_CURS_BLUE1       0x8a
#define VID506_CRTTV_INK_CURS_GREEN1      0x8b
#define VID506_CRTTV_INK_CURS_RED1        0x8c
#define VID506_CRTTV_INK_CURS_FIFO        0x8e
#define VID506_BITBLT_CTRL0               0x100
#define VID506_BITBLT_CTRL1               0x101
#define VID506_BITBLT_ROP_CODE            0x102
#define VID506_BITBLT_OPERATION           0x103
#define VID506_BITBLT_SRC_START_ADDR0     0x104
#define VID506_BITBLT_SRC_START_ADDR1     0x105
#define VID506_BITBLT_SRC_START_ADDR2     0x106
#define VID506_BITBLT_DEST_START_ADDR0    0x108
#define VID506_BITBLT_DEST_START_ADDR1    0x109
#define VID506_BITBLT_DEST_START_ADDR2    0x10a
#define VID506_BITBLT_MEM_ADDR_OFFSET0    0x10c
#define VID506_BITBLT_MEM_ADDR_OFFSET1    0x10d
#define VID506_BITBLT_WIDTH0              0x110
#define VID506_BITBLT_WIDTH1              0x111
#define VID506_BITBLT_HEIGHT0             0x112
#define VID506_BITBLT_HEIGHT1             0x113
#define VID506_BITBLT_BACKGND_COLOR0      0x114
#define VID506_BITBLT_BACKGND_COLOR1      0x115
#define VID506_BITBLT_FOREGND_COLOR0      0x118
#define VID506_BITBLT_FOREGND_COLOR1      0x119
#define VID506_LUT_MODE                   0x1e0
#define VID506_LUT_ADDR                   0x1e2
#define VID506_LUT_DATA                   0x1e4
#define VID506_PWR_SAVE_CFG               0x1f0
#define VID506_PWR_SAVE_STATUS            0x1f1
#define VID506_CPU2MEM_WATCHDOG           0x1f4
#define VID506_DISPLAY_MODE               0x1fc
#define VID506_MEDIAPLUG_LCMD             0x1000
#define VID506_MEDIAPLUG_RESERVED_LCMD    0x1002
#define VID506_MEDIAPLUG_CMD              0x1004
#define VID506_MEDIAPLUG_RESERVED_CMD     0x1006
#define VID506_MEDIAPLUG_DATA             0x1008

#endif /* !_SCR_FRYEBOX_H */
